@@ -91,7 +91,7 @@ namespace dht
 		KBucket::Ptr right(new KBucket(m + 1, max_key, srv, our_id));
 
 		QList<KBucketEntry>::iterator i;
-		for (i = entries.begin();i != entries.end();i++)
+		for (i = entries.begin();i != entries.end();++i)
 		{
 			KBucketEntry & e = *i;
 			if (left->keyInRange(e.getID()))
@@ -170,7 +170,7 @@ namespace dht
 
 		// replace the entry which timed out
 		QList<KBucketEntry>::iterator i;
-		for (i = entries.begin();i != entries.end();i++)
+		for (i = entries.begin();i != entries.end();++i)
 		{
 			KBucketEntry & e = *i;
 			if (e.getAddress() == c->getRequest()->getOrigin())
@@ -202,7 +202,7 @@ namespace dht
 
 		QList<KBucketEntry>::iterator i;
 		// we haven't found any bad ones so try the questionable ones
-		for (i = entries.begin();i != entries.end();i++)
+		for (i = entries.begin();i != entries.end();++i)
 		{
 			KBucketEntry & e = *i;
 			if (e.isQuestionable())
@@ -226,7 +226,7 @@ namespace dht
 	bool KBucket::replaceBadEntry(const KBucketEntry & entry)
 	{
 		QList<KBucketEntry>::iterator i;
-		for (i = entries.begin();i != entries.end();i++)
+		for (i = entries.begin();i != entries.end();++i)
 		{
 			KBucketEntry & e = *i;
 			if (e.isBad())
@@ -252,7 +252,7 @@ namespace dht
 		while (i != entries.end())
 		{
 			kns.tryInsert(*i);
-			i++;
+			++i;
 		}
 	}
 
@@ -260,7 +260,7 @@ namespace dht
 	{
 		QList<KBucketEntry>::iterator i;
 
-		for (i = entries.begin();i != entries.end();i++)
+		for (i = entries.begin();i != entries.end();++i)
 		{
 			KBucketEntry & e = *i;
 			if (e.getAddress() == addr)
@@ -299,7 +299,7 @@ namespace dht
 		enc.write(QByteArrayLiteral("entries"));
 		enc.beginList();
 		QList<KBucketEntry>::iterator i;
-		for (i = entries.begin();i != entries.end();i++)
+		for (i = entries.begin();i != entries.end();++i)
 		{
 			enc.beginDict();
 			KBucketEntry & e = *i;
