@@ -112,12 +112,12 @@ namespace bt
 		/// Get the status string
 		const QString getStatusString() const;
 		
-	private slots:
+	private Q_SLOTS:
 		void hostResolved(net::AddressResolver* ar);
 		void connectTimeout();
 		void replyTimeout();
 		
-	signals:
+	Q_SIGNALS:
 		void startReplyTimer(int timeout);
 		void stopReplyTimer();
 		void stopConnectTimer();
