@@ -18,7 +18,7 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.             *
  ***************************************************************************/
 #include "authenticatebase.h"
-#include <mse/streamsocket.h>
+#include <mse/encryptedpacketsocket.h>
 #include <util/sha1hash.h>
 #include <util/log.h>
 #include <dht/dhtbase.h>
@@ -28,11 +28,20 @@
 namespace bt
 {
 	
-	
-
-	AuthenticateBase::AuthenticateBase(mse::StreamSocket*  s) : sock(s),finished(false),local(false)
+	AuthenticateBase::AuthenticateBase() : finished(false),local(false)
 	{
-		connect(&timer,SIGNAL(timeout()),this,SLOT(onTimeout()));
+		connect(&timer, &QTimer::timeout, this, &AuthenticateBase::onTimeout);
+		timer.setSingleShot(true);
+		timer.start(5000);
+		memset(handshake,0x00,68);
+		bytes_of_handshake_received = 0;
+		ext_support = 0;
+	}
+
+
+	AuthenticateBase::AuthenticateBase(mse::EncryptedPacketSocket::Ptr  s) : sock(s),finished(false),local(false)
+	{
+		connect(&timer, &QTimer::timeout, this, &AuthenticateBase::onTimeout);
 		timer.setSingleShot(true);
 		timer.start(5000);
 		memset(handshake,0x00,68);
@@ -43,8 +52,6 @@ namespace bt
 
 	AuthenticateBase::~AuthenticateBase()
 	{
-		if (sock)
-			sock->deleteLater();
 	}
 
 	void AuthenticateBase::sendHandshake(const SHA1Hash & info_hash,const PeerID & our_peer_id)
@@ -155,4 +162,3 @@ namespace bt
 	void AuthenticateBase::onReadyWrite()
 	{}
 }
-#include "authenticatebase.moc"
