@@ -50,7 +50,7 @@ public:
     }
 
 
-private slots:
+private Q_SLOTS:
     void initTestCase()
     {
         QLocale::setDefault(QLocale("main"));
