@@ -48,7 +48,7 @@ class ResourceManagerTest : public QObject
 	Q_OBJECT
 public:
 	
-private slots:
+private Q_SLOTS:
 	void initTestCase()
 	{
 		bt::InitLog("resourcemanagertest.log");
