@@ -140,7 +140,7 @@ public:
 	{
 	}
 	
-public slots:
+public Q_SLOTS:
 	void accepted()
 	{
 		incoming = srv.acceptedConnection().toStrongRef();
@@ -160,7 +160,7 @@ public slots:
 		exit();
 	}
 	
-private slots:
+private Q_SLOTS:
 	void initTestCase()
 	{
 		bt::InitLog("transmittest.log",false,true,false);
